Attributes of Cartesian classes

PyGeodesy | 26.3.26 | class Cartesian in module
|  | pygeodesy.ellipsoidal- | pygeodesy.spherical-
attribute | type | -Exact | -Karney | -Nvector | -Vincenty | -Nvector | -Trigonometry
angleTo | method | E | E | E | E | E | E
apply | method | E | E | E | E | E | E
attrs | method | H | H | H | H | H | H
bearing | method | D | D | D | D | D | D
bools | method | E | E | E | E | E | E
cassini | method | C | C | C | C | C | C
circin6 | method | D | D | D | D | D | D
circum3 | method | D | D | D | D | D | D
circum4_ | method | D | D | D | D | D | D
classname | Property* | H | H | H | H | H | H
classnaming | property | H | H | H | H | H | H
classof | method | H | H | H | H | H | H
cmp | method | E | E | E | E | E | E
collins** | method | C | C | C | C | C | C
collins5 | method | C | C | C | C | C | C
convertDatum** | method | C | C | C | C | C | C
convertRefFrame** | method | B | B | B | B | - | -
copy | method | H | H | H | H | H | H
cross | method | E | E | E | E | E | E
crosserrors | property | E | E | E | E | E | E
datum | property | C | C | C | C | C | C
destinationXyz | method | C | C | C | C | C | C
dividedBy | method | E | E | E | E | E | E
dividedBy_ | method | E | E | E | E | E | E
dot | method | E | E | E | E | E | E
dup | method | H | H | H | H | H | H
Ecef | property* | G | G | A | A | G | G
ellipsoidalCartesian | property* | B | B | B | B | C | C
epoch | property | B | B | B | B | - | -
equals** | method | E | E | E | E | E | E
equirectangular | method | E | E | E | E | E | E
euclid | Property* | E | E | E | E | E | E
fabs | method | E | E | E | E | E | E
floats | method | E | E | E | E | E | E
floorDividedBy | method | E | E | E | E | E | E
floorDividedBy_ | method | E | E | E | E | E | E
hartzell | method | C | C | C | C | C | C
height | Property | C | C | C | C | C | C
height3 | method | C | C | C | C | C | C
height4 | method | C | C | C | C | C | C
homogeneous | property* | E | E | E | E | E | E
intermediateTo | method | E | E | E | E | E | E
intersections2 | method | B | B | B | B | B | B
ints | method | E | E | E | E | E | E
iscolinearWith | method | D | D | D | D | D | D
isconjugateTo | method | E | E | E | E | E | E
isEllipsoidal | Property* | C | C | C | C | C | C
isequalTo | method | E | E | E | E | E | E
isSpherical | Property* | C | C | C | C | C | C
iteration | property* | H | H | H | H | H | H
latlon | Property* | C | C | C | C | C | C
latlonheight | Property* | C | C | C | C | C | C
latlonheightdatum | Property* | C | C | C | C | C | C
length | Property* | E | E | E | E | E | E
length2 | Property* | E | E | E | E | E | E
meeus2 | method | D | D | D | D | D | D
methodname | method | H | H | H | H | H | H
minus | method | E | E | E | E | E | E
minus_ | method | E | E | E | E | E | E
name | property | H | H | H | H | H | H
named | Property* | H | H | H | H | H | H
named2 | Property* | H | H | H | H | H | H
named3 | Property* | H | H | H | H | H | H
named4 | Property* | H | H | H | H | H | H
nearestOn | method | D | D | D | D | D | D
nearestOn6 | method | D | D | D | D | D | D
negate | method | E | E | E | E | E | E
others | method | E | E | E | E | E | E
parse | method | D | D | D | D | D | D
philam | Property* | C | C | C | C | C | C
philamheight | Property* | C | C | C | C | C | C
philamheightdatum | Property* | C | C | C | C | C | C
pierlot | method | C | C | C | C | C | C
pierlotx | method | C | C | C | C | C | C
plus | method | E | E | E | E | E | E
plus_ | method | E | E | E | E | E | E
pow | method | E | E | E | E | E | E
radii11 | method | D | D | D | D | D | D
reframe | property | B | B | B | B | - | -
rename | method | H | H | H | H | H | H
renamed | method | H | H | H | H | H | H
Roc2 | method | C | C | C | C | C | C
rotate | method | E | E | E | E | E | E
rotateAround** | method | E | E | E | E | E | E
sizeof | property* | H | H | H | H | H | H
soddy4 | method | D | D | D | D | D | D
sphericalCartesian | property* | C | C | C | C | B | B
sum | method | E | E | E | E | E | E
tienstra** | method | C | C | C | C | C | C
tienstra7 | method | C | C | C | C | C | C
times | method | E | E | E | E | E | E
times_ | method | E | E | E | E | E | E
to2ab** | method | C | C | C | C | C | C
to2ll** | method | C | C | C | C | C | C
to3llh** | method | C | C | C | C | C | C
to3xyz** | method | E | E | E | E | E | E
toAer | method | G | G | G | G | G | G
toCartesian | method | D | D | D | D | D | D
toDatum | method | C | C | C | C | C | C
toEcef | method | C | C | C | C | C | C
toEnu | method | G | G | G | G | G | G
toLatLon | method | A | A | A | A | A | A
toLocal | method | G | G | G | G | G | G
toLtp | method | G | G | G | G | G | G
toNed | method | G | G | G | G | G | G
toNvector | method | C | C | A | C | A | C
toRefFrame | method | B | B | B | B | - | -
toRepr | method | F | F | F | F | F | F
toRtp | method | C | C | C | C | C | C
toStr | method | C | C | C | C | C | C
toStr2** | method | H | H | H | H | H | H
toTransform | method | C | C | C | C | C | C
toTransforms_** | method | B | B | B | B | - | -
toVector | method | C | C | C | C | C | C
toXyz | method | G | G | G | G | G | G
trilaterate2d2 | method | D | D | D | D | D | D
trilaterate3d2 | method | D | D | D | D | D | D
typename | property* | H | H | H | H | H | H
unit | method | E | E | E | E | E | E
x | Property | E | E | E | E | E | E
x2y2z2 | Property* | E | E | E | E | E | E
x2y2z23 | property* | E | E | E | E | E | E
xyz | Property | E | E | E | E | E | E
xyz3 | property* | E | E | E | E | E | E
y | Property | E | E | E | E | E | E
z | Property | E | E | E | E | E | E
**) DEPRECATED | *) immutable | A: class attribute | B, C, ...: attribute of a super class